OC.L10N.register(
    "forms",
    {
    "No" : "Ne",
    "Yes" : "Jes",
    "Copy" : "Kopii",
    "Shared with you" : "Kunhavata kun vi",
    "Select groups" : "Elekti grupojn",
    "Cancel" : "Cancel",
    "Required" : "Nepra",
    "Maximum file size" : "Maksimuma dosiergrando",
    "Delete" : "Forigi",
    "Other" : "Alia",
    "never" : "neniam",
    "Set expiration date" : "Uzi limdaton",
    "Group" : "Grupo",
    "Share link" : "Kunhavigi ligilon",
    "Add link" : "Aldoni ligilon",
    "Copy to clipboard" : "Kopii tondejen",
    "Internal link" : "Interna ligilo",
    "View" : "Vidi",
    "Edit" : "Modifi",
    "View mode" : "Vida reĝimo",
    "Share" : "Kunhavigi",
    "Description" : "Priskribo",
    "Summary" : "Resumo",
    "Download" : "Elŝuti",
    "Search" : "Serĉi",
    "Sharing" : "Kunhavigo",
    "Settings" : "Agordoj",
    "Submit" : "Sendi",
    "Clear" : "Viŝi",
    "Cannot copy, please copy the link manually" : "Ne eblis kopii la ligilon; kopiu ĝin permane.",
    "No recommendations. Start typing." : "Neniu propono. Ektajpu.",
    "No elements found." : "Nenio trovita.",
    "File" : "Dosiero",
    "Date" : "Date",
    "Time" : "Dato",
    "Color" : "Koloro",
    "Text" : "Teksto",
    "Phone number" : "Telefonnumero",
    "Email address" : "Retpoŝtadreso",
    "Uploading …" : "Alŝutado…"
},
"nplurals=2; plural=(n != 1);");
